@@ -1,13 +1,13 @@
 import { browser } from 'protractor';
 
-import { appHost, checkLogs, checkErrors, testName } from '../protractor.conf';
+import { appHost, checkLogs, checkErrors } from '../protractor.conf';
 import * as crudView from '../views/crud.view';
 import * as clusterSettingsView from '../views/cluster-settings.view';
 import * as horizontalnavView from '../views/horizontal-nav.view';
 
 describe('Cluster Settings', () => {
   beforeEach(async () => {
-    await browser.get(`${appHost}/settings/cluster/${testName}`);
+    await browser.get(`${appHost}/settings/cluster`);
     await crudView.isLoaded();
   });
 
@@ -18,15 +18,15 @@ describe('Cluster Settings', () => {
 
   it('display page title, horizontal navigation tab headings and pages', async () => {
     expect(clusterSettingsView.heading.isPresent()).toBe(true);
-    await horizontalnavView.clickHorizontalTab('Overview');
+    await horizontalnavView.clickHorizontalTab('Details');
     await crudView.isLoaded();
-    await horizontalnavView.clickHorizontalTab('Cluster Operators');
+    await horizontalnavView.clickHorizontalTab('ClusterOperators');
     await crudView.isLoaded();
-    await horizontalnavView.clickHorizontalTab('Global Configuration');
+    await horizontalnavView.clickHorizontalTab('Global configuration');
     await crudView.isLoaded();
   });
   it('display overview channel update modal, select value and click cancel', async () => {
-    await horizontalnavView.clickHorizontalTab('Overview');
+    await horizontalnavView.clickHorizontalTab('Details');
     await crudView.isLoaded();
     expect(clusterSettingsView.channelUpdateLink.isDisplayed()).toBe(true);
     await clusterSettingsView.channelUpdateLink.click();
@@ -44,7 +44,7 @@ describe('Cluster Settings', () => {
     await crudView.isLoaded();
   });
   it('display Cluster Operators page, click resource item link to display details. Check if the resource link title equals the details page header', async () => {
-    await horizontalnavView.clickHorizontalTab('Cluster Operators');
+    await horizontalnavView.clickHorizontalTab('ClusterOperators');
     await crudView.isLoaded();
 
     expect(clusterSettingsView.clusterOperatorResourceLink.isDisplayed()).toBe(true);
@@ -57,8 +57,8 @@ describe('Cluster Settings', () => {
     await horizontalnavView.clickHorizontalTab('YAML');
     await crudView.isLoaded();
   });
-  it('display Global Configuration page, click Configuration Resource item link and display details. Check if the resource link title equals the details page header', async () => {
-    await horizontalnavView.clickHorizontalTab('Global Configuration');
+  it('display Global configuration page, click Configuration Resource item link and display details. Check if the resource link title equals the details page header', async () => {
+    await horizontalnavView.clickHorizontalTab('Global configuration');
     await crudView.isLoaded();
 
     expect(clusterSettingsView.globalConfigResourceLink.isDisplayed()).toBe(true);
@@ -71,22 +71,22 @@ describe('Cluster Settings', () => {
     await horizontalnavView.clickHorizontalTab('YAML');
     await crudView.isLoaded();
   });
-  it('display Global Configuration page, click dropdown link to edit resource and display details, and check if details header is correct.', async () => {
-    await horizontalnavView.clickHorizontalTab('Global Configuration');
+  it('display Global configuration page, click dropdown link to edit resource and display details, and check if details header is correct.', async () => {
+    await horizontalnavView.clickHorizontalTab('Global configuration');
     await crudView.isLoaded();
 
     await clusterSettingsView.globalConfigResourceRow.click();
     await crudView.isLoaded();
 
-    expect(crudView.actionForLabel('Edit Console Resource').isDisplayed()).toBe(true);
-    await crudView.actionForLabel('Edit Console Resource').click();
+    expect(crudView.actionForLabel('Edit Console resource').isDisplayed()).toBe(true);
+    await crudView.actionForLabel('Edit Console resource').click();
     await crudView.isLoaded();
 
     expect(clusterSettingsView.clusterResourceDetailsTitle.isDisplayed()).toBe(true);
     expect(clusterSettingsView.clusterResourceDetailsTitle.getText()).toBe('cluster');
   });
-  it('display Global Configuration page, click Explore Console API in dropdown link and display details, and check if details header is correct.', async () => {
-    await horizontalnavView.clickHorizontalTab('Global Configuration');
+  it('display Global configuration page, click Explore Console API in dropdown link and display details, and check if details header is correct.', async () => {
+    await horizontalnavView.clickHorizontalTab('Global configuration');
     await crudView.isLoaded();
 
     await clusterSettingsView.globalConfigResourceRow.click();
@@ -95,7 +95,7 @@ describe('Cluster Settings', () => {
     expect(crudView.actionForLabel('Explore Console API').isDisplayed()).toBe(true);
     await crudView.actionForLabel('Explore Console API').click();
 
-    expect(clusterSettingsView.globalConfigDetailsTitle.isDisplayed()).toBe(true);
+    await clusterSettingsView.globalConfigDetailsTitleIsLoaded();
     expect(clusterSettingsView.globalConfigDetailsTitle.getText()).toBe('Console');
   });
 });
