@@ -2,4 +2,6 @@ export type StatusComponentProps = {
   title?: string;
   iconOnly?: boolean;
   noTooltip?: boolean;
+  className?: string;
+  popoverTitle?: string;
 };
