@@ -1,5 +1,6 @@
 import * as React from 'react';
 import * as _ from 'lodash';
+import { Trans, useTranslation } from 'react-i18next';
 import { k8sCreate, ContainerPort } from '@console/internal/module/k8s';
 import { ImageStreamImportsModel } from '@console/internal/models';
 import { useFormikContext, FormikValues, FormikTouched } from 'formik';
@@ -12,12 +13,13 @@ import {
 } from '@patternfly/react-core';
 import { SecretTypeAbstraction } from '@console/internal/components/secrets/create-secret';
 import { InputField, useDebounceCallback, CheckboxField } from '@console/shared';
+import { UNASSIGNED_KEY, CREATE_APPLICATION_KEY } from '@console/topology/src/const';
 import { getSuggestedName, getPorts, makePortName } from '../../../utils/imagestream-utils';
 import { secretModalLauncher } from '../CreateSecretModal';
-import { UNASSIGNED_KEY, CREATE_APPLICATION_KEY } from '../../../const';
 import './ImageSearch.scss';
 
 const ImageSearch: React.FC = () => {
+  const { t } = useTranslation();
   const { values, setFieldValue, dirty, initialValues, touched } = useFormikContext<FormikValues>();
   const [newImageSecret, setNewImageSecret] = React.useState('');
   const [alertVisible, shouldHideAlert] = React.useState(true);
@@ -105,7 +107,7 @@ const ImageSearch: React.FC = () => {
     ],
   );
 
-  const debouncedHandleSearch = useDebounceCallback(handleSearch, [handleSearch]);
+  const debouncedHandleSearch = useDebounceCallback(handleSearch);
 
   const handleSave = React.useCallback(
     (name: string) => {
@@ -117,10 +119,10 @@ const ImageSearch: React.FC = () => {
 
   const getHelpText = () => {
     if (values.isSearchingForImage) {
-      return 'Validating...';
+      return `${t('devconsole~Validating')}...`;
     }
     if (!values.isSearchingForImage && validated === ValidatedOptions.success) {
-      return 'Validated';
+      return t('devconsole~Validated');
     }
     return '';
   };
@@ -166,7 +168,7 @@ const ImageSearch: React.FC = () => {
       <InputField
         type={TextInputTypes.text}
         name="searchTerm"
-        placeholder="Enter an image name"
+        placeholder={t('devconsole~Enter an Image name')}
         helpText={getHelpText()}
         helpTextInvalid={helpTextInvalid}
         validated={validated}
@@ -180,35 +182,37 @@ const ImageSearch: React.FC = () => {
         required
       />
       <div className="help-block" id="image-name-help">
-        To deploy an image from a private repository, you must{' '}
-        <Button
-          variant="link"
-          isInline
-          onClick={() =>
-            secretModalLauncher({
-              namespace,
-              save: handleSave,
-              secretType: SecretTypeAbstraction.image,
-            })
-          }
-        >
-          create an image pull secret
-        </Button>{' '}
-        with your image registry credentials.
+        <Trans ns="devconsole" t={t}>
+          To deploy an Image from a private repository, you must{' '}
+          <Button
+            variant="link"
+            isInline
+            onClick={() =>
+              secretModalLauncher({
+                namespace,
+                save: handleSave,
+                secretType: SecretTypeAbstraction.image,
+              })
+            }
+          >
+            create an Image pull secret
+          </Button>{' '}
+          with your Image registry credentials.
+        </Trans>
       </div>
       {newImageSecret && alertVisible && (
         <Alert
           isInline
           className="co-alert"
           variant="success"
-          title={`Secret ${newImageSecret} was created.`}
+          title={t('devconsole~Secret {{newImageSecret}} was created.', newImageSecret)}
           actionClose={<AlertActionCloseButton onClose={() => shouldHideAlert(false)} />}
         />
       )}
       <div className="odc-image-search__advanced-options">
         <CheckboxField
           name="allowInsecureRegistry"
-          label="Allow images from insecure registries"
+          label={t('devconsole~Allow Images from insecure registries')}
           onChange={(val: boolean) => {
             values.searchTerm && handleSearch(values.searchTerm, val);
           }}
