@@ -12,9 +12,13 @@ export const detailsPage = {
       .contains(action)
       .click();
   },
+  isLoaded: () => cy.byTestID('skeleton-detail-view').should('not.exist'),
 };
 
 export namespace DetailsPageSelector {
   export const name = 'dd[data-test-selector="details-item-value__Name"]';
   export const namespace = 'dd[data-test-selector="details-item-value__Namespace"] a';
+  export const sectionHeadings = '[data-test-section-heading]';
+  export const itemLabels = 'dt';
+  export const horizontalNavTabs = '.co-m-horizontal-nav__menu-item';
 }
