@@ -1,25 +1,19 @@
-import {
-  COMMON_TEMPLATES_NAMESPACE,
-  COMMON_TEMPLATES_REVISION,
-  commonTemplateVersion,
-} from '../consts';
+import { testName } from '@console/internal-integration-tests/protractor.conf';
+import { COMMON_TEMPLATES_NAMESPACE, COMMON_TEMPLATES_REVISION } from '../constants/common';
 
-export const getWindowsVM = ({ name, networkName, vmIP }) => `
+export const getFakeWindowsVM = ({ name, networkName, vmIP }) => `
 apiVersion: kubevirt.io/v1alpha3
 kind: VirtualMachine
 metadata:
   annotations:
-    kubevirt.io/latest-observed-api-version: v1alpha3
-    kubevirt.io/storage-observed-api-version: v1alpha3
-    name.os.template.kubevirt.io/win2k16: Microsoft Windows Server 2016
+    name.os.template.kubevirt.io/win2k12r2: Microsoft Windows Server 2012 R2
   name: ${name}
+  namespace: ${testName}
   labels:
     app: ${name}
-    os.template.kubevirt.io/win2k16: 'true'
-    vm.kubevirt.io/template: win2k12r2-server-large-${commonTemplateVersion()}
+    os.template.kubevirt.io/win2k12r2: 'true'
     vm.kubevirt.io/template.namespace: ${COMMON_TEMPLATES_NAMESPACE}
     vm.kubevirt.io/template.revision: '${COMMON_TEMPLATES_REVISION}'
-    vm.kubevirt.io/template.version: ${commonTemplateVersion()}
     workload.template.kubevirt.io/server: 'true'
 spec:
   running: true
@@ -29,7 +23,7 @@ spec:
       labels:
         kubevirt.io/domain: ${name}
         kubevirt.io/size: large
-        os.template.kubevirt.io/win2k16: 'true'
+        os.template.kubevirt.io/win2k12r2: 'true'
         vm.kubevirt.io/name: ${name}
         workload.template.kubevirt.io/server: 'true'
     spec:
@@ -95,7 +89,7 @@ spec:
       terminationGracePeriodSeconds: 0
       volumes:
         - containerDisk:
-            image: 'kubevirt/fedora-cloud-registry-disk-demo:latest'
+            image: 'quay.io/kubevirt/fedora-cloud-container-disk-demo:latest'
           name: rootdisk
         - containerDisk:
             image: kubevirt/virtio-container-disk
@@ -106,9 +100,9 @@ spec:
               password: fedora
               chpasswd: { expire: False }
               runcmd:
-              - ifconfig eth1 ${vmIP} netmask 255.255.255.0 up
               - dnf install -y qemu-guest-agent
               - systemctl start qemu-guest-agent
+              - ifconfig eth1 ${vmIP} netmask 255.255.255.0 up
           name: cloudinitdisk
 status: {}
 `;
