@@ -8,15 +8,16 @@ import {
   removeLeakableResource,
   waitForCount,
 } from '@console/shared/src/test-utils/utils';
-import { getVMIManifest } from './utils/mocks';
+import { getVMIManifest } from './mocks/mocks';
 import {
+  VM_ACTIONS_TIMEOUT_SECS,
   VM_DELETE_TIMEOUT_SECS,
-  VMI_ACTION,
   VM_IMPORT_TIMEOUT_SECS,
-  VM_STATUS,
-} from './utils/consts';
+} from './utils/constants/common';
 import { VirtualMachineInstance } from './models/virtualMachineInstance';
+import { VM_STATUS, VMI_ACTION } from './utils/constants/vm';
 import { BaseVirtualMachine } from './models/baseVirtualMachine';
+import { ProvisionSource } from './utils/constants/enums/provisionSource';
 
 const waitForVM = async (manifest: any, status: VM_STATUS, resourcesSet: Set<string>) => {
   const vmi = new VirtualMachineInstance(manifest.metadata);
@@ -43,17 +44,21 @@ describe('Test VMI actions', () => {
     let testVMI: any;
 
     beforeAll(async () => {
-      testVMI = getVMIManifest('Container', testName, `vm-list-actions-${testName}`);
+      testVMI = getVMIManifest(ProvisionSource.CONTAINER, testName, `vm-list-actions-${testName}`);
       vmi = await waitForVM(testVMI, VM_STATUS.Running, leakedResources);
     }, VM_IMPORT_TIMEOUT_SECS);
 
-    it('ID(CNV-3693) Deletes VMI', async () => {
-      await vmi.navigateToListView();
+    it(
+      'ID(CNV-3693) Deletes VMI',
+      async () => {
+        await vmi.navigateToListView();
 
-      await vmi.listViewAction(VMI_ACTION.Delete, false);
-      removeLeakableResource(leakedResources, testVMI);
-      await waitForVMDeleted(vmi);
-    });
+        await vmi.listViewAction(VMI_ACTION.Delete, false);
+        removeLeakableResource(leakedResources, testVMI);
+        await waitForVMDeleted(vmi);
+      },
+      VM_ACTIONS_TIMEOUT_SECS,
+    );
   });
 
   describe('Test VMI detail view actions dropdown', () => {
@@ -61,14 +66,22 @@ describe('Test VMI actions', () => {
     let testVMI: any;
 
     beforeAll(async () => {
-      testVMI = getVMIManifest('Container', testName, `vm-detail-actions-${testName}`);
+      testVMI = getVMIManifest(
+        ProvisionSource.CONTAINER,
+        testName,
+        `vm-detail-actions-${testName}`,
+      );
       vmi = await waitForVM(testVMI, VM_STATUS.Running, leakedResources);
     }, VM_IMPORT_TIMEOUT_SECS);
 
-    it('ID(CNV-3699) Deletes VMI', async () => {
-      await vmi.action(VMI_ACTION.Delete, false);
-      removeLeakableResource(leakedResources, testVMI);
-      await waitForVMDeleted(vmi);
-    });
+    it(
+      'ID(CNV-3699) Deletes VMI',
+      async () => {
+        await vmi.action(VMI_ACTION.Delete, false);
+        removeLeakableResource(leakedResources, testVMI);
+        await waitForVMDeleted(vmi);
+      },
+      VM_ACTIONS_TIMEOUT_SECS,
+    );
   });
 });
