@@ -64,7 +64,7 @@ export const VirtualMachineInstanceMigrationModel: K8sKind = {
 export const DataVolumeModel: K8sKind = {
   label: 'Data Volume',
   labelPlural: 'Data Volumes',
-  apiVersion: 'v1alpha1',
+  apiVersion: 'v1beta1',
   apiGroup: 'cdi.kubevirt.io',
   plural: 'datavolumes',
   abbr: 'DV',
@@ -100,11 +100,59 @@ export const OVirtProviderModel: K8sKind = {
 export const VirtualMachineImportModel: K8sKind = {
   label: 'Virtual Machine Import',
   labelPlural: 'Virtual Machine Imports',
-  apiVersion: 'v1alpha1',
+  apiVersion: 'v1beta1',
   apiGroup: 'v2v.kubevirt.io',
   plural: 'virtualmachineimports',
-  abbr: 'VMImport',
+  abbr: 'VIM',
   namespaced: true,
   kind: 'VirtualMachineImport',
   id: 'virtualmachineimport',
 };
+
+export const UploadTokenRequestModel: K8sKind = {
+  label: 'Upload Token Request',
+  labelPlural: 'Upload Token Requests',
+  apiVersion: 'v1beta1',
+  apiGroup: 'upload.cdi.kubevirt.io',
+  namespaced: true,
+  plural: 'uploadtokenrequests',
+  abbr: 'utr',
+  kind: 'UploadTokenRequest',
+  id: 'uploadtokenrequest',
+};
+
+export const CDIConfigModel: K8sKind = {
+  label: 'CDI Config',
+  labelPlural: 'CDI Configs',
+  apiVersion: 'v1beta1',
+  apiGroup: 'cdi.kubevirt.io',
+  namespaced: false,
+  plural: 'cdiconfigs',
+  abbr: 'cdic',
+  kind: 'CDIConfig',
+  id: 'cdiconfig',
+};
+
+export const VirtualMachineSnapshotModel: K8sKind = {
+  label: 'Virtual Machine Snapshot',
+  labelPlural: 'Virtual Machine Snapshots',
+  apiVersion: 'v1alpha1',
+  apiGroup: 'snapshot.kubevirt.io',
+  plural: 'virtualmachinesnapshots',
+  abbr: 'VMS',
+  namespaced: true,
+  kind: 'VirtualMachineSnapshot',
+  id: 'virtualmachinesnapshot',
+};
+
+export const VirtualMachineRestoreModel: K8sKind = {
+  label: 'Virtual Machine Restore',
+  labelPlural: 'Virtual Machine Restores',
+  apiVersion: 'v1alpha1',
+  apiGroup: 'snapshot.kubevirt.io',
+  plural: 'virtualmachinerestores',
+  abbr: 'VMR',
+  namespaced: true,
+  kind: 'VirtualMachineRestore',
+  id: 'virtualmachinerestore',
+};
