@@ -9,6 +9,7 @@ import {
   ChartVoronoiContainer,
   getCustomTheme,
   ChartGroup,
+  ChartAreaProps,
 } from '@patternfly/react-charts';
 import { global_warning_color_100 as warningColor } from '@patternfly/react-tokens/dist/js/global_warning_color_100';
 import { global_danger_color_100 as dangerColor } from '@patternfly/react-tokens/dist/js/global_danger_color_100';
@@ -19,15 +20,18 @@ import { PrometheusEndpoint } from './helpers';
 import { PrometheusGraph, PrometheusGraphLink } from './prometheus-graph';
 import { usePrometheusPoll } from './prometheus-poll-hook';
 import { areaTheme } from './themes';
-import { DataPoint, CursorVoronoiContainer } from './';
+import {
+  DataPoint,
+  CursorVoronoiContainer,
+  DEFAULT_PROMETHEUS_SAMPLES,
+  DEFAULT_PROMETHEUS_TIMESPAN,
+} from './';
 import { mapLimitsRequests } from './utils';
 import { GraphEmpty } from './graph-empty';
 import { ChartLegendTooltip } from './tooltip';
 
 const DEFAULT_HEIGHT = 180;
-const DEFAULT_SAMPLES = 60;
 const DEFAULT_TICK_COUNT = 3;
-const DEFAULT_TIMESPAN = 60 * 60 * 1000; // 1 hour
 
 export enum AreaChartStatus {
   ERROR = 'ERROR',
@@ -51,12 +55,14 @@ export const AreaChart: React.FC<AreaChartProps> = ({
   query,
   tickCount = DEFAULT_TICK_COUNT,
   title,
-  ariaChartLabel,
+  ariaChartLinkLabel,
+  ariaChartTitle,
   xAxis = true,
   yAxis = true,
   chartStyle,
   byteDataType = '',
   showAllTooltip,
+  ...rest
 }) => {
   // Note: Victory incorrectly typed ThemeBaseProps.padding as number instead of PaddingProps
   // @ts-ignore
@@ -76,11 +82,20 @@ export const AreaChart: React.FC<AreaChartProps> = ({
     [processedData],
   );
 
-  const tickFormat = React.useCallback((tick) => `${humanize(tick, unit, unit).string}`, [
+  const xTickFormat = React.useCallback((tick) => formatDate(tick), [formatDate]);
+  const yTickFormat = React.useCallback((tick) => `${humanize(tick, unit, unit).string}`, [
     humanize,
     unit,
   ]);
 
+  const domain = React.useMemo<AreaChartProps['domain']>(
+    () => ({
+      ...(allZero && { y: [0, 1] }),
+      ...(rest.domain ?? {}),
+    }),
+    [allZero, rest.domain],
+  );
+
   const getLabel = React.useCallback(
     (prop, includeDate = true) => {
       const { x, y } = prop.datum as DataPoint<Date>;
@@ -122,8 +137,9 @@ export const AreaChart: React.FC<AreaChartProps> = ({
   return (
     <PrometheusGraph className={className} ref={containerRef} title={title}>
       {processedData?.length ? (
-        <PrometheusGraphLink query={query} ariaChartLabel={ariaChartLabel}>
+        <PrometheusGraphLink query={query} ariaChartLinkLabel={ariaChartLinkLabel}>
           <Chart
+            ariaTitle={ariaChartTitle || title}
             containerComponent={container}
             domainPadding={{ y: 20 }}
             height={height}
@@ -131,10 +147,10 @@ export const AreaChart: React.FC<AreaChartProps> = ({
             theme={theme}
             scale={{ x: 'time', y: 'linear' }}
             padding={padding}
-            {...(allZero && { domain: { y: [0, 1] } })}
+            domain={domain}
           >
-            {xAxis && <ChartAxis tickCount={tickCount} tickFormat={formatDate} />}
-            {yAxis && <ChartAxis dependentAxis tickCount={tickCount} tickFormat={tickFormat} />}
+            {xAxis && <ChartAxis tickCount={tickCount} tickFormat={xTickFormat} />}
+            {yAxis && <ChartAxis dependentAxis tickCount={tickCount} tickFormat={yTickFormat} />}
             <ChartGroup>
               {processedData.map((datum, index) => (
                 <ChartArea
@@ -155,52 +171,50 @@ export const AreaChart: React.FC<AreaChartProps> = ({
 };
 
 export const Area: React.FC<AreaProps> = ({
+  endTime,
   namespace,
   query,
   limitQuery,
   requestedQuery,
-  samples = DEFAULT_SAMPLES,
+  samples = DEFAULT_PROMETHEUS_SAMPLES,
   timeout,
-  timespan = DEFAULT_TIMESPAN,
+  timespan = DEFAULT_PROMETHEUS_TIMESPAN,
   ...rest
 }) => {
-  const [utilization, , utilizationLoading] = usePrometheusPoll({
+  const prometheusPollProps = {
     endpoint: PrometheusEndpoint.QUERY_RANGE,
+    endTime,
     namespace,
-    query,
     samples,
     timeout,
     timespan,
+  };
+
+  const [utilization, , utilizationLoading] = usePrometheusPoll({
+    query,
+    ...prometheusPollProps,
   });
   const [limit, , limitLoading] = usePrometheusPoll({
-    endpoint: PrometheusEndpoint.QUERY_RANGE,
-    namespace,
     query: limitQuery,
-    samples,
-    timeout,
-    timespan,
+    ...prometheusPollProps,
   });
   const [requested, , requestedLoading] = usePrometheusPoll({
-    endpoint: PrometheusEndpoint.QUERY_RANGE,
-    namespace,
     query: requestedQuery,
-    samples,
-    timeout,
-    timespan,
+    ...prometheusPollProps,
   });
+
+  const loading = utilizationLoading && limitLoading && requestedLoading;
   const { data, chartStyle } = mapLimitsRequests(utilization, limit, requested);
-  const loading =
-    utilizationLoading &&
-    (limitQuery ? limitLoading : true) &&
-    (requestedQuery ? requestedLoading : true);
+
   return (
-    <AreaChart data={data} loading={loading} query={query} chartStyle={chartStyle} {...rest} />
+    <AreaChart chartStyle={chartStyle} data={data} loading={loading} query={query} {...rest} />
   );
 };
 
 export type AreaChartProps = {
   className?: string;
-  formatDate?: (date: Date) => string;
+  domain?: ChartAreaProps['domain'];
+  formatDate?: (date: Date, showSeconds?: boolean) => string;
   humanize?: Humanize;
   height?: number;
   loading?: boolean;
@@ -208,7 +222,8 @@ export type AreaChartProps = {
   theme?: any; // TODO figure out the best way to import VictoryThemeDefinition
   tickCount?: number;
   title?: string;
-  ariaChartLabel?: string;
+  ariaChartLinkLabel?: string;
+  ariaChartTitle?: string;
   data?: DataPoint[][];
   xAxis?: boolean;
   yAxis?: boolean;
@@ -219,6 +234,7 @@ export type AreaChartProps = {
 };
 
 type AreaProps = AreaChartProps & {
+  endTime?: number;
   namespace?: string;
   query: string;
   samples?: number;
