@@ -13,13 +13,13 @@ import { Checkbox } from '../checkbox';
 import { PersistentVolumeClaimModel } from '../../models';
 import { StorageClass } from '../storage-class-form';
 import {
-  cephRBDProvisionerSuffix,
   provisionerAccessModeMapping,
   initialAccessModes,
   accessModeRadios,
   volumeModeRadios,
   dropdownUnits,
   getAccessModeForProvisioner,
+  getVolumeModeForProvisioner,
 } from './shared';
 
 const InfoToolTip = () => (
@@ -43,6 +43,7 @@ const NameValueEditorComponent = (props) => (
 export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
   const [accessModeHelp, setAccessModeHelp] = React.useState('Permissions to the mounted drive.');
   const [allowedAccessModes, setAllowedAccessModes] = React.useState(initialAccessModes);
+  const [allowedVolumeModes, setAllowedVolumeModes] = React.useState([]);
   const [storageClass, setStorageClass] = React.useState('');
   const [pvcName, setPvcName] = React.useState('');
   const [accessMode, setAccessMode] = React.useState('ReadWriteOnce');
@@ -97,14 +98,7 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
 
       if (storageClass) {
         obj.spec.storageClassName = storageClass;
-
-        // should set block only for RBD + RWX
-        if (
-          _.endsWith(storageProvisioner, cephRBDProvisionerSuffix) &&
-          accessMode === 'ReadWriteMany'
-        ) {
-          obj.spec.volumeMode = 'Block';
-        }
+        obj.spec.volumeMode = volumeMode;
       }
 
       return obj;
@@ -124,6 +118,12 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
     volumeMode,
   ]);
 
+  React.useEffect(() => {
+    const volumeModes = getVolumeModeForProvisioner(storageProvisioner, accessMode);
+    setVolumeMode(volumeModes.includes(volumeMode) ? volumeMode : volumeModes[0]);
+    setAllowedVolumeModes(volumeModes);
+  }, [accessMode, storageProvisioner, volumeMode]);
+
   const handleNameValuePairs = ({ nameValuePairs: updatedNameValuePairs }) => {
     setNameValuePairs(updatedNameValuePairs);
   };
@@ -292,6 +292,7 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
               inline
               checked={radio.value === volumeMode}
               name="volumeMode"
+              disabled={!allowedVolumeModes.includes(radio.value)}
             />
           ))
         )}
