@@ -2,7 +2,7 @@ import * as React from 'react';
 import { Link } from 'react-router-dom';
 import * as _ from 'lodash-es';
 import * as classNames from 'classnames';
-
+import { useTranslation } from 'react-i18next';
 import {
   ContainerSpec,
   K8sKind,
@@ -22,14 +22,15 @@ import {
   SectionHeading,
   VolumeType,
 } from './utils';
-import { Table, TableData, TableRow } from './factory';
+import { Table } from './factory';
 import { sortable } from '@patternfly/react-table';
 import { removeVolumeModal } from './modals';
 import { connectToModel } from '../kinds';
 
 const removeVolume = (kind: K8sKind, obj: K8sResourceKind, volume: RowVolumeData): KebabOption => {
   return {
-    label: 'Remove Volume',
+    // t('public~Remove volume')
+    labelKey: 'public~Remove volume',
     callback: () =>
       removeVolumeModal({
         kind,
@@ -98,38 +99,107 @@ const volumeRowColumnClasses = [
   Kebab.columnClass,
 ];
 
-const VolumesTableHeader = () => {
-  return [
+const VolumesTableRows = ({ componentProps: { data } }) => {
+  return _.map(data, (volume: RowVolumeData) => {
+    const { container, mountPath, name, readOnly, resource, subPath, volumeDetail } = volume;
+    const pod = getPodTemplate(resource);
+    return [
+      {
+        title: name,
+        props: {
+          className: volumeRowColumnClasses[0],
+          'data-test-volume-name-for': name,
+        },
+      },
+      {
+        title: mountPath,
+        props: {
+          classname: volumeRowColumnClasses[1],
+          'data-test-mount-path-for': name,
+        },
+      },
+      {
+        title: subPath || <span className="text-muted">No subpath</span>,
+        props: {
+          classname: volumeRowColumnClasses[2],
+        },
+      },
+      {
+        title: <VolumeType volume={volumeDetail} namespace={resource.metadata.namespace} />,
+        props: {
+          classname: volumeRowColumnClasses[3],
+        },
+      },
+      {
+        title: readOnly ? 'Read-only' : 'Read/Write',
+        props: {
+          classname: volumeRowColumnClasses[4],
+        },
+      },
+      {
+        title:
+          _.get(pod, 'kind') === 'Pod' ? (
+            <ContainerLink name={container} pod={pod as PodKind} />
+          ) : (
+            container
+          ),
+        props: {
+          classname: volumeRowColumnClasses[5],
+        },
+      },
+      {
+        title: (
+          <VolumeKebab
+            actions={menuActions}
+            kind={resource.kind}
+            resource={resource}
+            rowVolumeData={volume}
+          />
+        ),
+        props: {
+          classname: volumeRowColumnClasses[6],
+        },
+      },
+    ];
+  });
+};
+
+export const VolumesTable = (props) => {
+  const { t } = useTranslation();
+  const { resource, ...tableProps } = props;
+  const data: RowVolumeData[] = getRowVolumeData(resource);
+  const pod: PodTemplate = getPodTemplate(resource);
+  const VolumesTableHeader = () => [
     {
-      title: 'Name',
+      title: t('public~Name'),
       sortField: 'name',
       transforms: [sortable],
       props: { className: volumeRowColumnClasses[0] },
     },
     {
-      title: 'Mount Path',
+      title: t('public~Mount path'),
       sortField: 'mountPath',
       transforms: [sortable],
       props: { className: volumeRowColumnClasses[1] },
     },
     {
-      title: 'SubPath',
+      title: t('public~SubPath'),
       sortField: 'subPath',
       transforms: [sortable],
       props: { className: volumeRowColumnClasses[2] },
     },
     {
-      title: 'Type',
+      title: t('public~Type'),
       props: { className: volumeRowColumnClasses[3] },
     },
     {
-      title: 'Permissions',
+      title: t('public~Permissions'),
       sortField: 'readOnly',
       transforms: [sortable],
       props: { className: volumeRowColumnClasses[4] },
     },
     {
-      title: 'Utilized By',
+      title: t('public~Utilized by'),
       sortField: 'container',
       transforms: [sortable],
       props: { className: volumeRowColumnClasses[5] },
@@ -139,69 +209,22 @@ const VolumesTableHeader = () => {
       props: { className: volumeRowColumnClasses[6] },
     },
   ];
-};
-VolumesTableHeader.displayName = 'VolumesTableHeader';
 
-const VolumesTableRow = ({ obj: volume, index, key, style }) => {
-  const { name, resource, readOnly, mountPath, subPath, volumeDetail } = volume;
-  const permission = readOnly ? 'Read-only' : 'Read/Write';
-  const pod: PodTemplate = getPodTemplate(resource);
-
-  return (
-    <TableRow id={`${name}-${mountPath}`} index={index} trKey={key} style={style}>
-      <TableData className={volumeRowColumnClasses[0]} data-test-id="name">
-        {name}
-      </TableData>
-      <TableData
-        className={classNames(volumeRowColumnClasses[1], 'co-break-word')}
-        data-test-id="path"
-      >
-        {mountPath}
-      </TableData>
-      <TableData className={volumeRowColumnClasses[2]}>{subPath}</TableData>
-      <TableData className={volumeRowColumnClasses[3]}>
-        <VolumeType volume={volumeDetail} namespace={resource.metadata.namespace} />
-      </TableData>
-      <TableData className={volumeRowColumnClasses[4]}>{permission}</TableData>
-      <TableData className={volumeRowColumnClasses[5]}>
-        {_.get(pod, 'kind') === 'Pod' ? (
-          <ContainerLink name={volume.container} pod={pod as PodKind} />
-        ) : (
-          <div>{volume.container}</div>
-        )}
-      </TableData>
-      <TableData className={volumeRowColumnClasses[6]}>
-        <VolumeKebab
-          actions={menuActions}
-          kind={resource.kind}
-          resource={resource}
-          rowVolumeData={volume}
-        />
-      </TableData>
-    </TableRow>
-  );
-};
-VolumesTableRow.displayName = 'VolumesTableRow';
-
-export const VolumesTable = (props) => {
-  const { resource, ...tableProps } = props;
-  const data: RowVolumeData[] = getRowVolumeData(resource);
-  const pod: PodTemplate = getPodTemplate(resource);
   return (
     <>
       {props.heading && <SectionHeading text={props.heading} />}
       {_.isEmpty(pod.spec.volumes) && !anyContainerWithVolumeMounts(pod.spec.containers) ? (
-        <EmptyBox label="Volumes" />
+        <EmptyBox label={t('public~Volumes')} />
       ) : (
         <Table
           {...tableProps}
-          aria-label="Volumes"
+          aria-label={t('public~Volumes')}
           loaded={true}
           label={props.heading}
           data={data}
           Header={VolumesTableHeader}
-          Row={VolumesTableRow}
-          virtualize
+          Rows={VolumesTableRows}
+          virtualize={false}
         />
       )}
     </>
@@ -219,9 +242,7 @@ const VolumeKebab = connectToModel((props: VolumeKebabProps) => {
   return (
     <Kebab
       options={options}
-      isDisabled={
-        isDisabled !== undefined ? isDisabled : _.get(resource.metadata, 'deletionTimestamp')
-      }
+      isDisabled={isDisabled !== undefined ? isDisabled : resource?.metadata?.deletionTimestamp}
     />
   );
 });
